@@ -97,6 +97,16 @@ void Battle::Leave()
 	m_serv.LeaveBattle(m_opts.battleid);
 }
 
+void Battle::OnPlayerTrueskillChanged(const std::string& NickName, double TrueSkill)
+{
+	for (user_map_t::size_type i = 0; i < GetNumUsers(); i++) {
+		User& u = GetUser(i);
+		if (TowxString(u.GetNick()).Lower() == TowxString(NickName)) {
+			u.SetTrueSkill(TrueSkill);
+			return;
+		}
+	}
+}
 
 void Battle::OnRequestBattleStatus()
 {
