@@ -17,26 +17,22 @@ lsl/battle/ibattle.cpp
 #include <wx/tokenzr.h>
 #include <wx/log.h>
 
-#include <list>
 #include <algorithm>
-#include <cmath>
-#include <set>
-#include <sstream>
 
 #include <lslunitsync/unitsync.h>
+#include <lslutils/globalsmanager.h>
 
-#include "lslutils/globalsmanager.h"
-#include "ibattle.h"
 #include "utils/conversion.h"
+#include "utils/lslconversion.h"
 #include "gui/uiutils.h"
-#include "settings.h"
 #include "gui/ui.h"
+#include "ibattle.h"
+#include "iserver.h"
+#include "settings.h"
 #include "spring.h"
 #include "springlobbyapp.h"
-#include "iserver.h"
 #include "serverselector.h"
 #include "log.h"
-#include "utils/lslconversion.h"
 
 
 IBattle::IBattle()
@@ -721,14 +717,15 @@ void IBattle::SetLocalMap(const std::string& mapname)
 const LSL::UnitsyncMap& IBattle::LoadMap()
 {
 	if ((!m_map_loaded) && (!m_host_map.name.empty())) {
-		try {
-			ASSERT_EXCEPTION(MapExists(false), _T("Map does not exist: ") + TowxString(m_host_map.name));
-			m_local_map = LSL::usync().GetMap(m_host_map.name);
-			bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
-			ASSERT_EXCEPTION(options_loaded, _T("couldn't load the map options"));
-			m_map_loaded = true;
-
-		} catch (...) {
+		if (MapExists(false)) { //Check if selected map available for engine?
+			try {
+				m_local_map = LSL::usync().GetMap(m_host_map.name);
+				bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
+				//TODO: maybe replace this with "silent" IF operator?
+				ASSERT_EXCEPTION(options_loaded, _T("couldn't load the map options"));
+				m_map_loaded = true;
+			} catch (...) {
+			}
 		}
 	}
 	return m_local_map;
@@ -771,13 +768,13 @@ void IBattle::SetLocalMod(const LSL::UnitsyncMod& mod)
 
 const LSL::UnitsyncMod& IBattle::LoadMod()
 {
-	assert(!m_host_mod.name.empty());
+	ASSERT_LOGIC(!m_host_mod.name.empty(), "m_host_mod.name.empty() is FALSE");
 	if (!m_mod_loaded) {
 		try {
-			ASSERT_EXCEPTION(ModExists(), _T("Mod does not exist."));
+			ASSERT_EXCEPTION(ModExists(), wxString::Format("Game does not exist: %s hash:%s", m_host_mod.name.c_str(), m_host_mod.hash.c_str()));
 			m_local_mod = LSL::usync().GetMod(m_host_mod.name);
 			bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_mod.name);
-			ASSERT_EXCEPTION(options_loaded, _T("couldn't load the mod options"));
+			ASSERT_EXCEPTION(options_loaded, _T("couldn't load the game options"));
 			m_mod_loaded = true;
 		} catch (...) {
 		}
@@ -908,7 +905,7 @@ bool IBattle::LoadOptionsPreset(const std::string& name)
 			}
 			SendHostInfo(IBattle::HI_StartRects);
 
-			unsigned int rectcount = FromwxString(options[_T("numrects")]);
+			const unsigned int rectcount = FromwxString(options[_T("numrects")]);
 			for (unsigned int loadrect = 0; loadrect < rectcount; loadrect++) {
 				int ally = FromwxString(options[_T("rect_") + TowxString(loadrect) + _T("_ally")]);
 				if (ally == 0)
@@ -1174,7 +1171,7 @@ void IBattle::GetBattleFromScript(bool loadmapmod)
 						teaminfos.StartPosX = team->GetInt("StartPosX", -1);
 						teaminfos.StartPosY = team->GetInt("StartPosY", -1);
 						teaminfos.AllyTeam = team->GetInt("AllyTeam", 0);
-						teaminfos.RGBColor = LSL::Util::ColorFromFloatString(team->GetString("RGBColor"));
+						teaminfos.RGBColor = LSL::lslColor::FromFloatString(team->GetString("RGBColor"));
 						teaminfos.SideName = team->GetString("Side", "");
 						teaminfos.Handicap = team->GetInt("Handicap", 0);
 						const int sidepos = LSL::Util::IndexInSequence(sides, teaminfos.SideName);
