@@ -24,21 +24,21 @@ lsl/networking/tasserver.cpp
 #include <algorithm>
 #include <map>
 
-#include "utils/base64.h"
-#include "utils/md5.h"
 #include "tasserver.h"
-#include "utils/tasutil.h"
-#include "utils/conversion.h"
 #include "serverevents.h"
 #include "socket.h"
 #include "log.h"
+#include "settings.h"
+#include "utils/base64.h"
+#include "utils/md5.h"
+#include "utils/tasutil.h"
+#include "utils/conversion.h"
 #include "utils/slconfig.h"
 #include "utils/version.h"
-#include "settings.h"
+#include <lslutils/misc.h>
 
 
 SLCONFIG("/Server/ExitMessage", "Using http://springlobby.info/", "Message which is send when leaving server");
-SLCONFIG("/General/CpuID", 0L, "CPUId to be used when logging int to lobbyserver");
 
 // times in milliseconds
 #define PING_TIME 30000
@@ -72,11 +72,6 @@ SLCONFIG("/General/CpuID", 0L, "CPUId to be used when logging int to lobbyserver
 myteamcolor:  Should be 32-bit signed integer in decimal form (e.g. 255 and not FF) where each color channel should occupy 1 byte (e.g. in hexdecimal: $00BBGGRR, B = blue, G = green, R = red). Example: 255 stands for $000000FF.
 
 */
-int ConvUserStatus(const UserStatus& us);
-UserStatus ConvTasclientstatus(const int);
-
-UserBattleStatus ConvTasbattlestatus(const int);
-int ConvTasbattlestatus(const UserBattleStatus);
 
 IBattle::StartType IntToStartType(int start);
 NatType IntToNatType(int nat);
@@ -205,8 +200,8 @@ bool TASServer::ExecuteSayCommand(const std::string& cmd)
 	} else if (subcmd == "/rename") {
 		if (arrayparams.size() != 2)
 			return false;
-		SendCmd("RENAMEACsize", arrayparams[1]);
-		sett().SetServerAccountNick(sett().GetDefaultServer(), TowxString(arrayparams[1])); // this code assumes that default server hasn't changed since login ( like it should atm )
+		SendCmd("RENAMEACCOUNT", arrayparams[1]); //FIXME: this assumes that the rename is successful!
+		sett().SetServerAccountNick(TowxString(GetServerName()), TowxString(arrayparams[1]));
 		return true;
 	} else if (subcmd == "/testmd5") {
 		ExecuteCommand("SERVERMSG", GetPasswordHash(params));
@@ -217,28 +212,41 @@ bool TASServer::ExecuteSayCommand(const std::string& cmd)
 	} else if (subcmd == "/quit") {
 		Disconnect();
 		return true;
-	} else if (subcmd == "/changepassword2") {
-		if (arrayparams.size() < 2) {
-			m_se->OnServerMessage("Missing parameter, usage: /changepassword2 newpassword");
-			return true;
-		}
-		const std::string oldpassword = STD_STRING(sett().GetServerAccountPass(TowxString(GetServerName())));
-		const std::string newpassword = GetPasswordHash(params);
-		if (oldpassword.empty() || !sett().GetServerAccountSavePass(TowxString(GetServerName()))) {
-			m_se->OnServerMessage("There is no saved password for this acsize, please use /changepassword oldpassword newpassword");
-			return true;
-		}
-		SendCmd("CHANGEPASSWORD", oldpassword + std::string(" ") + newpassword);
-		return true;
 	} else if (subcmd == "/changepassword") {
-		if (arrayparams.size() != 3) {
-			m_se->OnServerMessage("Invalid parameter size, usage: /changepassword oldpassword newpassword");
-			return true;
+		switch (arrayparams.size()) {
+			case 2: {
+				const std::string oldpassword = GetPasswordHash(STD_STRING(sett().GetServerAccountPass(TowxString(GetServerName()))));
+				const std::string newpassword = GetPasswordHash(params);
+				if (oldpassword == newpassword) {
+					m_se->OnServerMessage("Old password is the same as the new password!");
+					return true;
+				}
+				if (params.empty()) {
+					m_se->OnServerMessage("No new password specified!");
+					return true;
+				}
+				if (oldpassword.empty()) {
+					m_se->OnServerMessage("Couldn't load old password!");
+					return true;
+				}
+				SendCmd("CHANGEPASSWORD", oldpassword + std::string(" ") + newpassword);
+				sett().SetServerAccountPass(TowxString(GetServerName()), TowxString(newpassword));
+				return true;
+			}
+			case 3: {
+				const std::string oldpassword = GetPasswordHash(arrayparams[1]);
+				const std::string newpassword = GetPasswordHash(arrayparams[2]);
+				SendCmd("CHANGEPASSWORD", oldpassword + std::string(" ") + newpassword);
+				return true;
+			}
+			default: {
+				m_se->OnServerMessage("Invalid usage, use:");
+				m_se->OnServerMessage("        /changepassword newpassword");
+				m_se->OnServerMessage("or, when password isn't stored:");
+				m_se->OnServerMessage("        /changepassword oldpassword newpassword");
+				return true;
+			}
 		}
-		const std::string oldpassword = GetPasswordHash(arrayparams[1]);
-		const std::string newpassword = GetPasswordHash(arrayparams[2]);
-		SendCmd("CHANGEPASSWORD", oldpassword + std::string(" ") + newpassword);
-		return true;
 	} else if (subcmd == "/ping") {
 		Ping();
 		return true;
@@ -278,12 +286,15 @@ void TASServer::Disconnect()
 		return;
 	}
 
+	if (IsConnected() == true) {
+		SendCmd("EXIT " + STD_STRING(cfg().ReadString(_T("/Server/ExitMessage")))); // EXIT command for new protocol compatibility
+		m_sock->Disconnect();
+	}
+
 	m_connected = false;
 	m_battle_id = -1;
-	SendCmd("EXIT " + STD_STRING(cfg().ReadString(_T("/Server/ExitMessage")))); // EXIT command for new protocol compatibility
-	m_sock->Disconnect();
-	delete m_sock;
-	m_sock = NULL;
+
+	wxDELETE(m_sock);
 }
 
 bool TASServer::IsConnected()
@@ -343,14 +354,16 @@ const User& TASServer::GetMe() const
 void TASServer::Login()
 {
 	slLogDebugFunc("");
+	if (m_sock == NULL) {
+		return;
+	}
 	const std::string pass = GetPasswordHash(GetPassword());
-	std::string localaddr = STD_STRING(m_sock->GetLocalAddress());
+	std::string localaddr = m_sock->GetLocalAddress();
 	if (localaddr.empty())
 		localaddr = "*";
 	m_id_transmission = false;
-	const int cpuid = cfg().ReadLong(_T("/General/CpuID"));
-	SendCmd("LOGIN", stdprintf("%s %s %d %s %s\t%u\ta m sp cl p",
-				   GetUserName().c_str(), pass.c_str(), cpuid, localaddr.c_str(), getSpringlobbyAgent().c_str(), m_crc.GetCRC()));
+	SendCmd("LOGIN", stdprintf("%s %s 0 %s %s\t%u\ta m sp cl p",
+				   GetUserName().c_str(), pass.c_str(), localaddr.c_str(), getSpringlobbyAgent().c_str(), m_crc.GetCRC()));
 	m_id_transmission = true;
 }
 
@@ -533,7 +546,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		contry = GetWordParam(params);
 		const int cpu = GetIntParam(params);
 		if (params.IsEmpty()) {
-			// if server didn't send any acsize id to us, fill with an always increasing number
+			// if server didn't send any account id to us, fill with an always increasing number
 			id = m_account_id_count;
 			m_account_id_count++;
 		} else {
@@ -547,7 +560,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 	} else if (cmd == "CLIENTSTATUS") {
 		nick = GetWordParam(params);
 		tasstatus = GetIntParam(params);
-		cstatus = ConvTasclientstatus(tasstatus);
+		cstatus = UserStatus::FromInt(tasstatus);
 		m_se->OnUserStatus(nick, cstatus);
 	} else if (cmd == "BATTLEOPENED") {
 		const int id = GetIntParam(params);
@@ -715,7 +728,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 	} else if (cmd == "CLIENTBATTLESTATUS") {
 		nick = GetWordParam(params);
 		tasbstatus = GetIntParam(params);
-		bstatus = ConvTasbattlestatus(tasbstatus);
+		bstatus = UserBattleStatus::FromInt(tasbstatus);
 		bstatus.colour = LSL::lslColor(GetIntParam(params));
 		m_se->OnClientBattleStatus(m_battle_id, nick, bstatus);
 	} else if (cmd == "ADDSTARTRECT") {
@@ -774,7 +787,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		nick = GetWordParam(params);
 		owner = GetWordParam(params);
 		tasbstatus = GetIntParam(params);
-		bstatus = ConvTasbattlestatus(tasbstatus);
+		bstatus = UserBattleStatus::FromInt(tasbstatus);
 		bstatus.colour = LSL::lslColor(GetIntParam(params));
 		wxString ai = TowxString(GetSentenceParam(params));
 		if (ai.empty()) {
@@ -792,7 +805,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		const int id = GetIntParam(params);
 		nick = GetWordParam(params);
 		tasbstatus = GetIntParam(params);
-		bstatus = ConvTasbattlestatus(tasbstatus);
+		bstatus = UserBattleStatus::FromInt(tasbstatus);
 		bstatus.colour = LSL::lslColor(GetIntParam(params));
 		m_se->OnBattleUpdateBot(id, nick, bstatus);
 		//UPDATEBOT BATTLE_ID name battlestatus teamcolor
@@ -851,9 +864,9 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 	} else if (cmd == "CLIENTIPPORT") {
 		// clientipport username ip port
 		nick = GetWordParam(params);
-		wxString ip = TowxString(GetWordParam(params));
+		const std::string ip = GetWordParam(params);
 		unsigned int u_port = (unsigned int)GetIntParam(params);
-		m_se->OnClientIPPort(nick, STD_STRING(ip), u_port);
+		m_se->OnClientIPPort(nick, ip, u_port);
 	} else if (cmd == "SETSCRIPTTAGS") {
 		wxString command;
 		while ((command = TowxString(GetSentenceParam(params))) != wxEmptyString) {
@@ -938,13 +951,10 @@ void TASServer::RelayCmd(const std::string& command, const std::string& param)
 		wxLogWarning(_T("Trying to send relayed commands but no relay bot is set!"));
 		return;
 	}
-	wxString wxcmd = TowxString(command);
-	wxString wxparam = TowxString(param);
-	wxString msg = _T("!"); // prefix commands with !
-	if (param.empty())
-		msg = wxcmd.Lower();
-	else
-		msg = wxcmd.Lower() + _T(" ") + wxparam;
+	wxString msg = _T("!") + TowxString(command).Lower(); // prefix commands with !
+	if (!param.empty()) {
+		msg += + _T(" ") + TowxString(param);
+	}
 	SayPrivate(m_relay_host_bot, STD_STRING(msg));
 }
 
@@ -1187,7 +1197,7 @@ void TASServer::AdminSetBotMode(const std::string& nick, bool isbot)
 }
 
 
-void TASServer::HostBattle(BattleOptions bo, const std::string& password)
+void TASServer::HostBattle(const BattleOptions& bo, const std::string& password)
 {
 	slLogDebugFunc("");
 
@@ -1198,24 +1208,23 @@ void TASServer::HostBattle(BattleOptions bo, const std::string& password)
 	nat_type=1;
 	}*/
 	wxLogMessage(_T("hosting with nat type %d"), nat_type);
-	wxString wxpassword = TowxString(password);
-	wxString cmd = wxString::Format(_T("0 %d "), nat_type);
-	cmd += (wxpassword.IsEmpty()) ? _T("*") : wxpassword;
-	cmd += wxString::Format(_T(" %d %d "), bo.port, bo.maxplayers);
-	cmd += TowxString(LSL::Util::MakeHashSigned(bo.modhash));
-	cmd += wxString::Format(_T(" %d "), bo.rankneeded);
-	cmd += TowxString(LSL::Util::MakeHashSigned(bo.maphash) + std::string(" "));
+	std::string cmd = stdprintf("0 %d ", nat_type);
+	cmd += (password.empty()) ? "*" : password;
+	cmd += stdprintf(" %d %d ", bo.port, bo.maxplayers);
+	cmd += LSL::Util::MakeHashSigned(bo.modhash);
+	cmd += stdprintf(" %d ", bo.rankneeded);
+	cmd += LSL::Util::MakeHashSigned(bo.maphash) + std::string(" ");
 	if (!bo.userelayhost) { //FIXME: relay host hasn't multiversion support yet, see https://github.com/springlobby/springlobby/issues/98
-		cmd += TowxString(bo.engineName) + _T("\t");
-		cmd += TowxString(bo.engineVersion) + _T("\t");
+		cmd += bo.engineName + std::string("\t");
+		cmd += bo.engineVersion + std::string("\t");
 	}
-	cmd += TowxString(bo.mapname) + _T("\t");
-	cmd += TowxString(bo.description) + _T("\t");
-	cmd += TowxString(bo.modname);
+	cmd += bo.mapname + std::string("\t");
+	cmd += LSL::Util::Replace(bo.description, "\t", "    ") + std::string("\t");
+	cmd += bo.modname;
 
 	m_delayed_open_command = "";
 	if (!bo.userelayhost) {
-		SendCmd("OPENBATTLE", STD_STRING(cmd));
+		SendCmd("OPENBATTLE", cmd);
 	} else {
 		if (bo.relayhost.empty()) {
 			LSL::StringVector relaylist = GetRelayHostList();
@@ -1224,12 +1233,12 @@ void TASServer::HostBattle(BattleOptions bo, const std::string& password)
 				srand(time(NULL));
 				unsigned int choice = rand() % numbots;
 				m_relay_host_manager = relaylist[choice];
-				m_delayed_open_command = STD_STRING(cmd);
+				m_delayed_open_command = cmd;
 				SayPrivate(m_relay_host_manager, "!spawn");
 			}
 		} else {
 			m_relay_host_manager = bo.relayhost;
-			m_delayed_open_command = STD_STRING(cmd);
+			m_delayed_open_command = cmd;
 			SayPrivate(bo.relayhost, "!spawn");
 		}
 	}
@@ -1477,7 +1486,7 @@ IBattle* TASServer::GetCurrentBattle()
 void TASServer::SendMyBattleStatus(UserBattleStatus& bs)
 {
 	slLogDebugFunc("");
-	const int tasbs = ConvTasbattlestatus(bs);
+	const int tasbs = UserBattleStatus::ToInt(bs);
 	//MYBATTLESTATUS battlestatus myteamcolor
 	SendCmd("MYBATTLESTATUS", stdprintf("%d %d", tasbs, bs.colour.GetLobbyColor()));
 }
@@ -1486,7 +1495,7 @@ void TASServer::SendMyBattleStatus(UserBattleStatus& bs)
 void TASServer::SendMyUserStatus(const UserStatus& us)
 {
 	slLogDebugFunc("");
-	const int taus = ConvUserStatus(us);
+	const int taus = UserStatus::ToInt(us);
 	SendCmd("MYSTATUS", stdprintf("%d", taus));
 }
 
@@ -1544,7 +1553,7 @@ void TASServer::ForceTeam(int battleid, User& user, int team)
 		return;
 	}
 	if (!GetBattle(battleid).IsFounderMe()) {
-		DoActionBattle(battleid, "suggests that " + user.GetNick() + " changes to team #" + stdprintf("%d", team + 1) + ".");
+		DoActionBattle(battleid, stdprintf("suggests that %s changes to team #%d.", user.GetNick().c_str(), team + 1));
 		return;
 	}
 
@@ -1571,12 +1580,12 @@ void TASServer::ForceAlly(int battleid, User& user, int ally)
 	}
 
 	if (!GetBattle(battleid).IsFounderMe()) {
-		DoActionBattle(battleid, "suggests that " + user.GetNick() + " changes to ally #" + stdprintf("%d", ally + 1) + ".");
+		DoActionBattle(battleid, stdprintf("suggests that %s changes to ally #%d.", user.GetNick().c_str(), ally + 1));
 		return;
 	}
 
 	//FORCEALLYNO username teamno
-	SendCmd("FORCEALLYNO", user.GetNick() + stdprintf(" %d", ally), GetBattle(battleid).IsProxy());
+	SendCmd("FORCEALLYNO", stdprintf("%s %d", user.GetNick().c_str(), ally), GetBattle(battleid).IsProxy());
 }
 
 
@@ -1601,7 +1610,7 @@ void TASServer::ForceColour(int battleid, User& user, const LSL::lslColor& col)
 	}
 
 	//FORCETEAMCOLOR username color
-	SendCmd("FORCETEAMCOLOR", user.GetNick() + std::string(" ") + stdprintf("%d", col.GetLobbyColor()), GetBattle(battleid).IsProxy());
+	SendCmd("FORCETEAMCOLOR", stdprintf("%s %d", user.GetNick().c_str(), col.GetLobbyColor()), GetBattle(battleid).IsProxy());
 }
 
 
@@ -1676,21 +1685,16 @@ void TASServer::SetHandicap(int battleid, User& user, int handicap)
 	}
 
 	//HANDICAP username value
-	SendCmd("HANDICAP", user.GetNick() + stdprintf(" %d", handicap), GetBattle(battleid).IsProxy());
+	SendCmd("HANDICAP", stdprintf("%s %d", user.GetNick().c_str(), handicap), GetBattle(battleid).IsProxy());
 }
 
 
 void TASServer::AddBot(int battleid, const std::string& nick, UserBattleStatus& status)
 {
 	CHECK_CURRENT_BATTLE_ID(battleid)
-
-	const int tasbs = ConvTasbattlestatus(status);
+	const int tasbs = UserBattleStatus::ToInt(status);
 	//ADDBOT name battlestatus teamcolor {AIDLL}
-	wxString msg;
-	wxString ailib;
-	ailib += TowxString(status.aishortname);
-	ailib += _T("|") + TowxString(status.aiversion);
-	SendCmd("ADDBOT", nick + stdprintf(" %d %d ", tasbs, status.colour.GetLobbyColor()) + STD_STRING(ailib));
+	SendCmd("ADDBOT", stdprintf("%s %d %d %s|%s", nick.c_str(), tasbs, status.colour.GetLobbyColor(), status.aishortname.c_str(), status.aiversion.c_str()));
 }
 
 
@@ -1714,9 +1718,9 @@ void TASServer::RemoveBot(int battleid, User& bot)
 void TASServer::UpdateBot(int battleid, User& bot, UserBattleStatus& status)
 {
 	CHECK_CURRENT_BATTLE_ID(battleid)
-	const int tasbs = ConvTasbattlestatus(status);
+	const int tasbs = UserBattleStatus::ToInt(status);
 	//UPDATEBOT name battlestatus teamcolor
-	SendCmd("UPDATEBOT", bot.GetNick() + stdprintf(" %d %d", tasbs, status.colour.GetLobbyColor()), GetBattle(battleid).IsProxy());
+	SendCmd("UPDATEBOT", stdprintf("%s %d %d", bot.GetNick().c_str(), tasbs, status.colour.GetLobbyColor()), GetBattle(battleid).IsProxy());
 }
 
 void TASServer::OnConnected()
@@ -1940,63 +1944,6 @@ LSL::StringVector TASServer::GetRelayHostList()
 // Utility functions
 //////////////////////
 
-int ConvUserStatus(const UserStatus& us)
-{
-	int taus = 0;
-	taus += (us.in_game ? 1 : 0);
-	taus += (us.away ? 1 : 0) << 1;
-	taus += (us.rank % 16) << 2;
-	taus += (us.moderator ? 1 : 0) << 5;
-	taus += (us.bot ? 1 : 0) << 6;
-	return taus;
-}
-
-
-UserStatus ConvTasclientstatus(const int tas)
-{
-	//http://springrts.com/dl/LobbyProtocol/ProtocolDescription.html#MYSTATUS:client
-	UserStatus stat;
-	stat.in_game = (tas >> 0) & 1;
-	stat.away = (tas >> 1) & 1;
-	stat.rank = (UserStatus::RankContainer)((tas >> 2) % 8);
-	stat.moderator = (tas >> 5) & 1;
-	stat.bot = (tas >> 6) & 1;
-	assert(ConvUserStatus(stat) == tas);
-	return stat;
-}
-
-UserBattleStatus ConvTasbattlestatus(const int tas)
-{
-	UserBattleStatus stat;
-	//http://springrts.com/dl/LobbyProtocol/ProtocolDescription.html#MYBATTLESTATUS:client
-	stat.ready = (tas >> 1) & 1;
-	stat.team = (tas >> 2) & 15;
-	stat.ally = (tas >> 6) & 15;
-	stat.spectator = ((tas >> 10) & 1) == 0;
-	stat.handicap = ((tas >> 11) & 127) % 101;
-	stat.sync = ((tas >> 22) & 3) % 3;
-	stat.side = (tas >> 24) & 15;
-	assert(tas == ConvTasbattlestatus(stat));
-	return stat;
-}
-
-
-int ConvTasbattlestatus(UserBattleStatus bs)
-{
-	int ret = 0;			     // b0 is reserved
-	ret += (bs.ready ? 1 : 0) << 1;      // b1
-	ret += (bs.team % 16) << 2;	  //b2..b5
-	ret += (bs.ally % 16) << 6;	  //b6..b9
-	ret += (bs.spectator ? 0 : 1) << 10; //b10
-	ret += (bs.handicap % 101) << 11;    //b11..b17
-	//b18..b21 reserverd
-	ret += (bs.sync % 3) << 22;  //b22..b23
-	ret += (bs.side % 16) << 24; //b24..b27
-	//b28..31 is unused
-	return ret;
-}
-
-
 IBattle::StartType IntToStartType(int start)
 {
 	switch (start) {
@@ -2043,3 +1990,22 @@ IBattle::GameType IntToGameType(int gt)
 	};
 	return IBattle::GT_ComContinue;
 }
+
+// send script.txt to relayhost
+void TASServer::SendScriptToProxy( const std::string& script )
+{
+	LSL::StringVector strings = LSL::Util::StringTokenize(script, "\n");
+	int relaylenghtprefix = 10 + 1 + m_relay_host_bot.length() + 2; // SAYPRIVATE + space + botname + space + exclamation mark lenght
+	int lenght = script.size();
+	lenght += relaylenghtprefix + 11 + 1; // CLEANSCRIPT command size
+	lenght += strings.size() * ( relaylenghtprefix + 16 + 1 ); // num lines * APPENDSCRIPTLINE + space command size ( \n is already counted in script.size)
+	lenght += relaylenghtprefix + 9 + 1; // STARTGAME command size
+	const int time = lenght / m_sock->GetSendRateLimit(); // calculate time in seconds to upload script
+	DoActionBattle( m_battle_id, stdprintf("is preparing to start the game, game will start in approximately %d seconds",time));
+	RelayCmd("CLEANSCRIPT");
+
+	for (const std::string& line: strings) {
+		RelayCmd("APPENDSCRIPTLINE", line);
+	}
+	RelayCmd("STARTGAME");
+}
